@@ -18,27 +18,25 @@ from fss.flaskr import app as flask_app
 from fss.freeze import freezer
 
 
-#noinspection PyUnusedLocal
-def build(args):
+#########################
+# Build                 #
+#########################
+
+def build():
     freezer.freeze()
 
 
-#noinspection PyUnusedLocal
-def dev_server(args):
+#########################
+# Dev Server            #
+#########################
+
+def dev_server():
     flask_app.run()
 
 
 if __name__ == '__main__':
-    import argparse
+    import argh
 
-    parser = argparse.ArgumentParser()
-    subparsers = parser.add_subparsers(title='Commands')
-
-    parser_build = subparsers.add_parser('build', help='Compile Jinja2 templates into static html pages')
-    parser_build.set_defaults(func=build)
-
-    parser_dev_server = subparsers.add_parser('dev_server', help='Start a local dev-server via Flask')
-    parser_dev_server.set_defaults(func=dev_server)
-
-    arguments = parser.parse_args()
-    arguments.func(arguments)
+    parser = argh.ArghParser()
+    parser.add_commands([build, dev_server])
+    parser.dispatch()
